==> pyglossary_4.5.0.orig.tar.gz: pyglossary-4.5.0/doc/p/dict_org.md <==
## DICT.org file format (.index)

### General Information

| Attribute       | Value                                                                        |
| --------------- | ---------------------------------------------------------------------------- |
| Name            | DictOrg                                                                      |
| snake_case_name | dict_org                                                                     |
| Description     | DICT.org file format (.index)                                                |
| Extensions      | `.index`                                                                     |
| Read support    | Yes                                                                          |
| Write support   | Yes                                                                          |
| Single-file     | No                                                                           |
| Kind            | 📁 directory                                                                  |
| Sort-on-write   | default_no                                                                   |
| Sort key        | (`headword_lower`)                                                           |
| Wiki            | [DICT#DICT file format](https://en.wikipedia.org/wiki/DICT#DICT_file_format) |
| Website         | [The DICT Development Group](http://dict.org/bin/Dict)                       |

### Write options

| Name    | Default | Type | Comment                                 |
| ------- | ------- | ---- | --------------------------------------- |
| dictzip | `False` | bool | Compress .dict file to .dict.dz         |
| install | `True`  | bool | Install dictionary to /usr/share/dictd/ |



### Dictionary Applications/Tools

| Name & Website                                                  | License | Platforms |
| --------------------------------------------------------------- | ------- | --------- |
| [Dictd](https://directory.fsf.org/wiki/Dictd)                   | GPL     | Linux     |
| [GNOME Dictionary](https://wiki.gnome.org/Apps/Dictionary)      | GPL     | Linux     |
| [Xfce4 Dictionary](https://docs.xfce.org/apps/xfce4-dict/start) | GPL     | linux     |
| [Ding](https://www-user.tu-chemnitz.de/~fri/ding/)              | GPL     | linux     |

==> pyglossary_5.0.9.orig.tar.gz: pyglossary-5.0.9/doc/p/dict_org.md <==
## DICT.org file format (.index)

### General Information

| Attribute       | Value                                                                        |
| --------------- | ---------------------------------------------------------------------------- |
| Name            | DictOrg                                                                      |
| snake_case_name | dict_org                                                                     |
| Description     | DICT.org file format (.index)                                                |
| Extensions      | `.index`                                                                     |
| Read support    | Yes                                                                          |
| Write support   | Yes                                                                          |
| Single-file     | No                                                                           |
| Kind            | 📁 directory                                                                  |
| Sort-on-write   | No (by default)                                                              |
| Sort key        | (`headword_lower`)                                                           |
| Wiki            | [DICT#DICT file format](https://en.wikipedia.org/wiki/DICT#DICT_file_format) |
| Website         | [The DICT Development Group](http://dict.org/bin/Dict)                       |

### Write options

| Name    | Default | Type | Comment                                 |
| ------- | ------- | ---- | --------------------------------------- |
| dictzip | `False` | bool | Compress .dict file to .dict.dz         |
| install | `True`  | bool | Install dictionary to /usr/share/dictd/ |

### Dictionary Applications/Tools

| Name & Website                                                  | Source code | License | Platforms | Language |
| --------------------------------------------------------------- | ----------- | ------- | --------- | -------- |
| [Dictd](https://directory.fsf.org/wiki/Dictd)                   | ―           | GPL     | Linux     |          |
| [GNOME Dictionary](https://wiki.gnome.org/Apps/Dictionary)      | ―           | GPL     | Linux     |          |
| [Xfce4 Dictionary](https://docs.xfce.org/apps/xfce4-dict/start) | ―           | GPL     | linux     |          |
| [Ding](https://www-user.tu-chemnitz.de/~fri/ding/)              | ―           | GPL     | linux     |          |
